==> haskell-stm-chans-3.0.0.4-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-CLOTnr5GvVqFfxSQvaCBDJ
key: stm-chans-3.0.0.4-CLOTnr5GvVqFfxSQvaCBDJ
license: BSD3
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
author: wren gayle romano, Thomas DuBuisson
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
abi: ec6b3419c8216301dd7c1b52fd6dbe78
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-CLOTnr5GvVqFfxSQvaCBDJ
depends:
    base-4.10.0.0 stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-chans-3.0.0.4-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-BLt16m2iw757MCn7otRDwn
key: stm-chans-3.0.0.4-BLt16m2iw757MCn7otRDwn
license: BSD3
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
author: wren gayle romano, Thomas DuBuisson
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
abi: c4dabb360e52736ad562f5e22fe08d66
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-BLt16m2iw757MCn7otRDwn
depends:
    base-4.10.1.0 stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=63c518eabfb1b430d925fb35cc544a7c
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
